@@ -1,6 +1,10 @@
 #![allow(non_snake_case, non_camel_case_types)]
 #![cfg_attr(test, allow(deref_nullptr))] // https://github.com/rust-lang/rust-bindgen/issues/2066
 
+// force linking to openssl
+#[cfg(feature = "bundled-sqlcipher-vendored-openssl")]
+extern crate openssl_sys;
+
 pub use self::error::*;
 
 use std::default::Default;
